@@ -2,8 +2,9 @@ import logging
 import os
 import shutil
 import sys
+from contextlib import contextmanager
 from pathlib import Path
-from typing import Union
+from typing import Iterator
 
 import attr
 import click
@@ -14,17 +15,21 @@ import bento.content.init as content
 import bento.git
 import bento.tool_runner
 from bento.commands.autorun import install_autorun
+from bento.commands.ci import install_ci, is_ci_configured, is_ci_provider_supported
 from bento.context import Context
 from bento.decorators import with_metrics
-from bento.util import echo_error
+from bento.error import NotAGitRepoException
 
 
-def _dim_filename(path: Union[Path, str]) -> str:
-    return f"{click.style(str(path), bold=True, dim=True)}"
+@contextmanager
+def interaction(context: click.Context) -> Iterator[None]:
+    context.obj.start_user_timer()
+    yield
+    context.obj.stop_user_timer()
 
 
 @attr.s(auto_attribs=True)
-class InitCommand(object):
+class InitCommand:
     context: Context
 
     def _install_config_if_not_exists(self) -> bool:
@@ -42,7 +47,7 @@ class InitCommand(object):
             ) as template:
                 yml = yaml.safe_load(template)
             for tid, tool in self.context.tool_inventory.items():
-                if not tool.matches_project(self.context) and tid in yml["tools"]:
+                if not tool(self.context).matches_project() and tid in yml["tools"]:
                     del yml["tools"][tid]
             logging.debug(
                 f"Matching tools for this project: {', '.join(yml['tools'].keys())}"
@@ -109,6 +114,49 @@ class InitCommand(object):
         else:
             content.InstallAutorun.install.echo(skip=True)
 
+    def _should_we_install_ci(self, ctx: click.Context) -> bool:
+        """
+        Returns boolean indicating whether CI should be installed.
+
+        The answer is no if CI isn't supported,
+        or if the user asks not to configure it.
+        """
+        if not is_ci_provider_supported(self.context.base_path):
+            return False
+
+        if is_ci_configured(self.context):
+            return False
+
+        if not sys.stdin.isatty() or not sys.stderr.isatty():
+            return False
+
+        content.InstallCI.pitch.echo()
+
+        with interaction(ctx):
+            is_confirmed = content.InstallCI.confirm.echo()
+
+        content.InstallCI.after_confirm.echo()
+        return is_confirmed
+
+    def _configure_ci(self, ctx: click.Context, is_ci_requested: bool) -> bool:
+        """
+        Sets up CI integration if the user asked for it.
+
+        Returns whether CI has been newly installed.
+        """
+        config_path = self.context.pretty_path(self.context.gh_actions_file_path)
+        config_directory = config_path.parts[0]
+
+        if not is_ci_requested or is_ci_configured(self.context):
+            content.InstallCI.progress.echo(config_directory, skip=True)
+            return False
+
+        on_done = content.InstallCI.progress.echo(config_directory)
+        ctx.invoke(install_ci)
+        on_done()
+
+        return True
+
     def _install_tools(self, clean: bool) -> None:
         """
         Ensures tools are installed
@@ -126,10 +174,7 @@ class InitCommand(object):
     def _identify_git(self) -> None:
         repo = bento.git.repo(self.context.base_path)
         if repo is None:
-            echo_error(
-                "Current directory is not part of a Git project. Bento only works for Git projects."
-            )
-            sys.exit(3)
+            raise NotAGitRepoException()
 
     def _identify_project(self) -> None:
         """Identifies this project"""
@@ -145,16 +190,19 @@ class InitCommand(object):
             return
         content.Identify.success.echo(projects)
 
-    def _finish(self) -> None:
+    def _finish(self, *, is_ci_newly_installed: bool) -> None:
         content.Finish.body.echo()
+        if is_ci_newly_installed:
+            content.InstallCI.finalize_ci.echo()
 
     def run(self, ctx: click.Context, clean: bool) -> None:
         content.Start.banner.echo()
 
+        is_ci_requested = self._should_we_install_ci(ctx)
+
         if sys.stdin.isatty() and sys.stderr.isatty():
-            ctx.obj.start_user_timer()
-            content.Start.confirm.echo(default=True, show_default=False)
-            ctx.obj.stop_user_timer()
+            with interaction(ctx):
+                content.Start.confirm.echo(default=True, show_default=False)
 
         self.context.resource_path.mkdir(exist_ok=True)
         is_first_init = not self.context.config_path.exists()
@@ -165,6 +213,7 @@ class InitCommand(object):
         self._install_ignore_if_not_exists()
         self._install_config_if_not_exists()
         self._configure_autorun(ctx, is_first_init)
+        is_ci_newly_installed = self._configure_ci(ctx, is_ci_requested)
 
         # Perform project identification
         self._identify_project()
@@ -173,7 +222,7 @@ class InitCommand(object):
         self._install_tools(clean)
 
         # Message next steps
-        self._finish()
+        self._finish(is_ci_newly_installed=is_ci_newly_installed)
 
 
 @click.command()
