@@ -3,7 +3,7 @@ import logging
 import os
 import re
 import subprocess
-from typing import Any, Dict, Iterable, List, Optional, Pattern, Type
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Pattern, Type
 
 from semantic_version import Version
 
@@ -13,6 +13,9 @@ from bento.tool import JsonR, JsonTool
 from bento.util import fetch_line_in_file
 from bento.violation import Violation
 
+if TYPE_CHECKING:
+    from docker.models.containers import Container
+
 
 def convert(obj: Dict[str, Any], target: str) -> Dict[str, Any]:
     """
@@ -118,7 +121,7 @@ class ShellcheckTool(JsonTool):
             filters={"name": self.CONTAINER_NAME, "status": "running"}
         )
         if not running_containers:
-            container = client.containers.run(
+            container: "Container" = client.containers.run(  # type: ignore
                 image_id,
                 command="/dev/fd/0",
                 tty=True,
