@@ -1,8 +1,7 @@
-import json
 import logging
+import resource
 import subprocess
 from abc import ABC, abstractmethod
-from fnmatch import fnmatch
 from pathlib import Path
 from time import time
 from typing import (
@@ -22,7 +21,8 @@ import attr
 
 from bento.base_context import BaseContext
 from bento.parser import Parser
-from bento.result import Violation
+from bento.result import Violation, from_cache_repr, to_cache_repr
+from bento.util import batched
 
 R = TypeVar("R")
 """Generic return type"""
@@ -31,6 +31,10 @@ JsonR = List[Dict[str, Any]]
 """Return type for tools with a JSON representation"""
 
 
+MIN_RESERVED_ARGS = 128
+"""Number of argument positions reserved for non-file command arguments (e.g. rule ignores)"""
+
+
 # Note: for now, every tool *HAS* to directly inherit from this, even if it
 # also inherits from JsTool or PythonTool. This is so we can list all tools by
 # looking at subclasses of Tool.
@@ -70,18 +74,6 @@ class Tool(ABC, Generic[R]):
         """Returns a description of what this tool tests"""
         pass
 
-    @classmethod
-    @abstractmethod
-    def serialize(cls, results: R) -> str:
-        """Converts a tool's output to its cache representation"""
-        pass
-
-    @classmethod
-    @abstractmethod
-    def deserialize(cls, rep: str) -> R:
-        """Converts a tool's cache representation to its parseable form"""
-        pass
-
     @property
     @abstractmethod
     def project_name(self) -> str:
@@ -128,36 +120,33 @@ class Tool(ABC, Generic[R]):
         """
         pass
 
-    @classmethod
     @abstractmethod
-    def matches_project(cls, context: BaseContext) -> bool:
+    def matches_project(self) -> bool:
         """
         Returns true if and only if this project should use this tool
         """
         pass
 
-    @classmethod
-    def project_has_extensions(cls, context: BaseContext, *extensions: str) -> bool:
+    def project_has_file_paths(self) -> bool:
         """
         Returns true iff any unignored files matches at least one extension
         """
-        file_matches = (
-            fnmatch(str(e.path), ext)
-            for e in context.file_ignores.entries()
-            if e.survives
-            for ext in extensions
-        )
-        return any(file_matches)
+        file_paths = (e.path for e in self.context.file_ignores.entries() if e.survives)
+        return any(self.filter_paths(file_paths))
 
     def _file_contains_shebang_pattern(self, file_path: Path) -> bool:
         """
             Checks if the first line of file_path matches self.shebang_pattern.
 
             Returns False if a "first line" does not make sense for file_path
-            i.e. file_path is a binary or is an empty file
+            i.e. file_path is a binary or is an empty file or doesnt exist
         """
         assert self.shebang_pattern is not None
 
+        if not file_path.is_file():
+            # File doesnt exist or is a dir
+            return False
+
         with open(file_path) as file:
             try:
                 line: str = next(file)
@@ -210,6 +199,37 @@ class Tool(ABC, Generic[R]):
         logging.debug(f"{self.tool_id()}: Command completed in {after - before:2f} s")
         return res
 
+    @staticmethod
+    def _max_batch_size() -> int:
+        """Returns the maximum number of files to run in a single batch"""
+        # On UNIX, max argc is stack size / 4
+        return int(resource.RLIMIT_STACK / 4) - MIN_RESERVED_ARGS
+
+    def _get_findings_from_run(self, paths: Iterable[Path]) -> List[Violation]:
+        """
+        Returns findings by calling tool "run" method
+
+        :param paths: Paths to run on
+        :return:
+        """
+        paths_to_run = self.filter_paths(paths)
+        if not paths_to_run:
+            return []
+
+        violations: List[Violation] = []
+
+        for batch in batched(paths_to_run, self._max_batch_size()):
+            path_list = [str(p) for p in batch]
+            raw = self.run(path_list)
+            try:
+                violations += self.parser().parse(raw)
+            except Exception as e:
+                raise Exception(
+                    f"Could not parse output of '{self.tool_id()}':\n{raw}", e
+                )
+
+        return violations
+
     def results(self, paths: List[Path], use_cache: bool = True) -> List[Violation]:
         """
         Runs this tool, returning all identified violations
@@ -226,50 +246,24 @@ class Tool(ABC, Generic[R]):
         Raises:
             CalledProcessError: If execution fails
         """
-        if paths:
-            logging.debug(f"Checking for local cache for {self.tool_id()}")
-            cache_repr = self.context.cache.get(self.tool_id(), paths)
-            if not use_cache or cache_repr is None:
-                logging.debug(
-                    f"Cache entry invalid for {self.tool_id()}. Running Tool."
-                )
-                paths_to_run = self.filter_paths(paths)
-                if not paths_to_run:
-                    return []
-                raw = self.run([str(p) for p in paths_to_run])
-                if use_cache:
-                    self.context.cache.put(self.tool_id(), paths, self.serialize(raw))
-            else:
-                raw = self.deserialize(cache_repr)
-
-            try:
-                violations = self.parser().parse(raw)
-            except Exception as e:
-                raise Exception(
-                    f"Could not parse output of '{self.tool_id()}':\n{raw}", e
-                )
-            ignore_set = set(self.config.get("ignore", []))
-            filtered = [v for v in violations if v.check_id not in ignore_set]
-            return filtered
-        else:
+        if not paths:
             return []
 
+        logging.debug(f"Checking for local cache for {self.tool_id()}")
+        cache_repr = self.context.cache.get(self.tool_id(), paths)
+        if not use_cache or cache_repr is None:
+            logging.debug(f"Cache entry invalid for {self.tool_id()}. Running Tool.")
+            violations = self._get_findings_from_run(paths)
+            if use_cache:
+                self.context.cache.put(self.tool_id(), paths, to_cache_repr(violations))
+        else:
+            violations = from_cache_repr(cache_repr)
 
-class StrTool(Tool[str]):
-    @classmethod
-    def serialize(cls, results: str) -> str:
-        return results
-
-    @classmethod
-    def deserialize(cls, rep: str) -> str:
-        return rep
+        ignore_set = set(self.config.get("ignore", []))
+        filtered = [v for v in violations if v.check_id not in ignore_set]
+        return filtered
 
 
-class JsonTool(Tool[JsonR]):
-    @classmethod
-    def serialize(cls, results: JsonR) -> str:
-        return json.dumps(results)
+StrTool = Tool[str]
 
-    @classmethod
-    def deserialize(cls, rep: str) -> JsonR:
-        return json.loads(rep)
+JsonTool = Tool[JsonR]
