@@ -4,7 +4,6 @@ import itertools
 import logging
 import os
 import os.path
-import pkgutil
 import re
 import shutil
 import signal
@@ -12,6 +11,7 @@ import subprocess
 import sys
 import threading
 import types
+from functools import partial
 from importlib import import_module
 from pathlib import Path
 from textwrap import wrap as py_wrap
@@ -21,6 +21,8 @@ from typing import (
     Collection,
     Dict,
     Generic,
+    Iterable,
+    Iterator,
     List,
     Optional,
     Pattern,
@@ -59,6 +61,13 @@ LINK_WIDTH = 2 * len(OSC_8) + 2 * len(BEL)
 AutocompleteSuggestions = List[Union[str, Tuple[str, str]]]
 
 
+class Colors:
+    LINK = "bright_blue"
+    ERROR = "red"
+    WARNING = "yellow"
+    SUCCESS = "green"
+
+
 def _calculate_print_width() -> int:
     term_width, _ = shutil.get_terminal_size((MAX_PRINT_WIDTH, 0))
     return max(min(MAX_PRINT_WIDTH, term_width), MIN_PRINT_WIDTH)
@@ -147,25 +156,20 @@ class Memo(Generic[M]):
 DO_PRINT_LINKS = is_child_process_of(LINK_PRINTER_PATTERN)
 
 
-def package_subclasses(tpe: Type, pkg_path: str) -> List[Type]:
-    """
-    Finds all subtypes of a type within a module path, relative to this module
+_T = TypeVar("_T")
 
-    Parameters:
-        tpe: The parent type
-        pkg_path: The path to search, written as a python identifier (e.g. bento.extra)
 
-    Returns:
-        A list of all subtypes
+def batched(it: Iterable[_T], max_len: int) -> Iterator[Iterator[_T]]:
     """
-    walk_path = os.path.join(
-        os.path.dirname(__file__), os.path.pardir, *pkg_path.split(".")
+    Batches an iterator in iterators of a maximum length
+
+    :param it: The iterator to batch
+    :param max_len: The maximum length
+    """
+    return (
+        (y for _, y in x)
+        for _, x in itertools.groupby(enumerate(it), key=lambda x: int(x[0] / max_len))
     )
-    for (_, name, ispkg) in pkgutil.walk_packages([walk_path]):
-        if name != "setup" and not ispkg:
-            import_module(f"{pkg_path}.{name}", __package__)
-
-    return tpe.__subclasses__()
 
 
 def less(
@@ -225,19 +229,37 @@ def wrap(text: str, extra: int = 0) -> str:
     return "\n".join(py_wrap(text, PRINT_WIDTH - 1 + extra))
 
 
-def echo_error(text: str, indent: str = "") -> None:
-    logging.error(text)
-    secho(wrap(f"{indent}✘ {text}"), fg=Colors.ERROR, err=True)
+def echo_styled(
+    text: str, icon: str, log_fn: Callable, fg: str, indent: str = ""
+) -> None:
+    """
+    Print operational messages to stderr with styling.
+    Comes with preconfigured functions for common styles:
+    `echo_error`, `echo_warning`, and `echo_success`
 
 
-def echo_warning(text: str, indent: str = "") -> None:
-    logging.warning(text)
-    secho(wrap(f"{indent}⚠ {text}"), fg=Colors.WARNING, err=True)
+    :param text: Text to print, will be wrapped line-by-line.
+    :param icon: An icon, emoji or otherwise, to prefix the first line with.
+    :param log_fn: A function to call with the raw text.
+                   Meant to write to log files in the appropriate format.
+    :param fg: A click-compatible color name to use as text color.
+    :param indent: A string to prepend to every line, such as "  " or "... "
+
+    >>> echo_error("ERROR\nTask failed successfully.", indent="  ")
+      ✘ ERROR
+      Task failed successfully.
+    """
+    log_fn(text)
+    prefix = f"{icon} "
+    lines = text.splitlines()
+    for line in lines:
+        secho(wrap(f"{indent}{prefix}{line}"), fg=fg, err=True)
+        prefix = ""
 
 
-def echo_success(text: str, indent: str = "") -> None:
-    logging.info(text)
-    secho(wrap(f"{indent}✔ {text}"), fg=Colors.SUCCESS, err=True)
+echo_error = partial(echo_styled, icon="✘", log_fn=logging.error, fg=Colors.ERROR)
+echo_warning = partial(echo_styled, icon="⚠", log_fn=logging.warning, fg=Colors.WARNING)
+echo_success = partial(echo_styled, icon="✔", log_fn=logging.info, fg=Colors.SUCCESS)
 
 
 def echo_box(text: str) -> None:
@@ -292,11 +314,6 @@ def echo_next_step(desc: str, cmd: str) -> None:
     echo_styles("◦ ", style(f"{desc}, run $ ", dim=True), cmd)
 
 
-def echo_wrap(text: str, **kwargs: Any) -> None:
-    """Prints a wrapped paragraph"""
-    secho(wrap(text), err=True, **kwargs)
-
-
 def echo_progress(text: str, extra: int = 0, skip: bool = False) -> Callable[[], None]:
     """
     Prints a binary in-progress / done bar
@@ -372,29 +389,3 @@ def append_text_to_file(file: Path, text: str) -> None:
     """
     with file.open("a") as fd:
         fd.write(f"\n{text}\n")
-
-
-# Taken from http://www.madhur.co.in/blog/2015/11/02/countdownlatch-python.html
-class CountDownLatch(object):
-    def __init__(self, count: int = 1):
-        self.count = count
-        self.lock = threading.Condition()
-
-    def count_down(self) -> None:
-        with self.lock:
-            self.count -= 1
-            if self.count <= 0:
-                self.lock.notifyAll()
-
-    def wait_for(self) -> None:
-        with self.lock:
-            while self.count > 0:
-                self.lock.wait()
-
-
-class Colors:
-    LINK = "bright_blue"
-    STATUS = "bright_blue"  # Deprecated in favor of bold / dim
-    ERROR = "red"
-    WARNING = "yellow"
-    SUCCESS = "green"
